summaryrefslogtreecommitdiff
path: root/lib/x509/x509.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/x509/x509.c')
-rw-r--r--lib/x509/x509.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/x509/x509.c b/lib/x509/x509.c
index abac2a8dba..2749016bb6 100644
--- a/lib/x509/x509.c
+++ b/lib/x509/x509.c
@@ -292,7 +292,7 @@ gnutls_x509_crt_import(gnutls_x509_crt_t cert,
}
if (cert->expanded) {
/* Any earlier asn1_der_decoding will modify the ASN.1
structure, so we need to replace it with a fresh
structure. */
result = crt_reinit(cert);
@@ -305,7 +305,7 @@ gnutls_x509_crt_import(gnutls_x509_crt_t cert,
cert->expanded = 1;
result =
- asn1_der_decoding(&cert->cert, cert->der.data, cert->der.size, NULL);
+ _asn1_strict_der_decode(&cert->cert, cert->der.data, cert->der.size, NULL);
if (result != ASN1_SUCCESS) {
result = _gnutls_asn2err(result);
gnutls_assert();
@@ -3832,7 +3832,7 @@ gnutls_x509_crt_get_authority_info_access(gnutls_x509_crt_t crt,
return _gnutls_asn2err(ret);
}
- ret = asn1_der_decoding(&c2, aia.data, aia.size, NULL);
+ ret = _asn1_strict_der_decode(&c2, aia.data, aia.size, NULL);
/* asn1_print_structure (stdout, c2, "", ASN1_PRINT_ALL); */
_gnutls_free_datum(&aia);
if (ret != ASN1_SUCCESS) {
@@ -292,7 +292,7 @@ gnutls_x509_crt_import(gnutls_x509_crt_t cert,
}
if (cert->expanded) {
- /* Any earlier asn1_der_decoding will modify the ASN.1
+ /* Any earlier _asn1_strict_der_decode will modify the ASN.1
structure, so we need to replace it with a fresh
structure. */